This is a dummy placeholder for the SparkBeyond Python SDK.<br>
The actual SDK can be installed directly from your Discovery Platform server. <br>
For further information, please contact `support@sparkbeyond.com`